@@ -56,8 +56,10 @@ def countdown_terminal():
     parser.add_argument('time', metavar ='time', type=str, nargs=1, help= 'time')
 
     args = parser.parse_args()
-
-    if countdown(args.time[0]):
-        print('Countdown finished.')
-    else:
-        print('Countdown failed.')
+    try:
+        if countdown(args.time[0]):
+            print('Countdown finished.')
+        else:
+            print('Countdown failed.')
+    except KeyboardInterrupt:
+        print('Countdown stopped.')
